==> owncloud-10.0.7.tgz: owncloud/apps/files/l10n/eu.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Biltegi bliogabea",
    "Unknown error" : "Errore ezezaguna",
    "All files" : "Fitxategi guztiak",
    "Saved" : "Gordeta",
    "Home" : "Etxekoa",
    "Close" : "Itxi",
    "Favorites" : "Gogokoak",
    "Upload cancelled." : "Igoera ezeztatuta",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ezin da {filename} igo karpeta bat delako edo 0 byte dituelako",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ez dago leku nahikorik, zu {size1} igotzen ari zara baina bakarrik {size2} libre dago",
    "Uploading..." : "Igotzen...",
    "..." : "...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Fitxategien igoera martxan da. Orria orain uzteak igoera ezeztatutko du.",
    "Actions" : "Ekintzak",
    "Download" : "Deskargatu",
    "Rename" : "Berrizendatu",
    "Delete" : "Ezabatu",
    "Disconnect storage" : "Deskonektatu biltegia",
    "Unshare" : "Ez elkarbanatu",
    "Files" : "Fitxategiak",
    "Details" : "Xehetasunak",
    "Select" : "hautatu",
    "Pending" : "Zain",
    "Unable to determine date" : "Ezin izan da data zehaztu",
    "Invalid path" : "Baliogabeko bidea",
    "Could not move \"{file}\"" : "Ezin da mugitu \"{file}\"",
    "Name" : "Izena",
    "Size" : "Tamaina",
    "Modified" : "Aldatuta",
    "_%n folder_::_%n folders_" : ["karpeta %n","%n karpeta"],
    "_%n file_::_%n files_" : ["fitxategi %n","%n fitxategi"],
    "{dirs} and {files}" : "{dirs} eta {files}",
    "You don’t have permission to upload or create files here" : "Ez duzu fitxategiak hona igotzeko edo hemen sortzeko baimenik",
    "_Uploading %n file_::_Uploading %n files_" : ["Fitxategi %n igotzen","%n fitxategi igotzen"],
    "New" : "Berria",
    "\"{name}\" is an invalid file name." : "\"{name}\" ez da fitxategi izen baliogarria.",
    "File name cannot be empty." : "Fitxategi izena ezin da hutsa izan.",
    "Your storage is full, files can not be updated or synced anymore!" : "Zure biltegiratzea beterik dago, ezingo duzu aurrerantzean fitxategirik igo edo sinkronizatu!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Zure biltegiratzea nahiko beterik dago (%{usedSpacePercent})",
    "Favorited" : "Gogokoa",
    "Favorite" : "Gogokoa",
    "Folder" : "Karpeta",
    "New folder" : "Karpeta berria",
    "Upload" : "Igo",
    "A new file or folder has been <strong>created</strong>" : "Fitxategi edo karpeta berri bat <strong>sortu da</strong>",
    "A file or folder has been <strong>changed</strong>" : "Fitxategi edo karpeta bat <strong>aldatu da</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Fitxategi edo karpeta bat <strong>ezabatu da</strong>",
    "A file or folder has been <strong>restored</strong>" : "Fitxategia edo karpeta <strong>berrezarri</strong> da",
    "You created %1$s" : "Zuk sortua %1$s",
    "%2$s created %1$s" : "%2$sk sortua %1$s",
    "%1$s was created in a public folder" : "%1$s sortu da karpeta publiko batean",
    "You changed %1$s" : "%1$s aldatu duzu",
    "%2$s changed %1$s" : "%2$sk aldatuta %1$s",
    "You deleted %1$s" : "%1$s ezabatu duzu",
    "%2$s deleted %1$s" : "%2$sk ezabatuta %1$s",
    "You restored %1$s" : "Zuk %1$s berrezarri duzu",
    "%2$s restored %1$s" : "%2$sk %1$s berrezarri du",
    "Upload (max. %s)" : "Igo (max. %s)",
    "File handling" : "Fitxategien kudeaketa",
    "Maximum upload size" : "Igo daitekeen gehienezko tamaina",
    "max. possible: " : "max, posiblea:",
    "Save" : "Gorde",
    "Settings" : "Ezarpenak",
    "WebDAV" : "WebDAV",
    "Upload some content or sync with your devices!" : "Igo edukiren bat edo sinkronizatu zure gailuekin!",
    "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan",
    "Select all" : "Hautatu dena",
    "Upload too large" : "Igoera handiegia da",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Igotzen saiatzen ari zaren fitxategiak zerbitzari honek igotzeko onartzen duena baino handiagoak dira.",
    "No favorites" : "Gogokorik ez",
    "Files and folders you mark as favorite will show up here" : "Gogokotzat markatutako fitxategi eta karpeta hemen agertuko dira",
    "Text file" : "Testu fitxategia"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/files/l10n/eu.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Biltegi bliogabea",
    "Unknown error" : "Errore ezezaguna",
    "All files" : "Fitxategi guztiak",
    "Saved" : "Gordeta",
    "Home" : "Etxekoa",
    "Close" : "Itxi",
    "Favorites" : "Gogokoak",
    "Upload cancelled." : "Igoera ezeztatuta",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ezin da {filename} igo karpeta bat delako edo 0 byte dituelako",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ez dago leku nahikorik, zu {size1} igotzen ari zara baina bakarrik {size2} libre dago",
    "Uploading..." : "Igotzen...",
    "..." : "...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Fitxategien igoera martxan da. Orria orain uzteak igoera ezeztatutko du.",
    "Actions" : "Ekintzak",
    "Download" : "Deskargatu",
    "Rename" : "Berrizendatu",
    "Delete" : "Ezabatu",
    "Disconnect storage" : "Deskonektatu biltegia",
    "Unshare" : "Ez elkarbanatu",
    "Files" : "Fitxategiak",
    "Details" : "Xehetasunak",
    "Select" : "hautatu",
    "Pending" : "Zain",
    "Unable to determine date" : "Ezin izan da data zehaztu",
    "Invalid path" : "Baliogabeko bidea",
    "Could not move \"{file}\"" : "Ezin da mugitu \"{file}\"",
    "Name" : "Izena",
    "Size" : "Tamaina",
    "Modified" : "Aldatuta",
    "_%n folder_::_%n folders_" : ["karpeta %n","%n karpeta"],
    "_%n file_::_%n files_" : ["fitxategi %n","%n fitxategi"],
    "{dirs} and {files}" : "{dirs} eta {files}",
    "You don’t have permission to upload or create files here" : "Ez duzu fitxategiak hona igotzeko edo hemen sortzeko baimenik",
    "_Uploading %n file_::_Uploading %n files_" : ["Fitxategi %n igotzen","%n fitxategi igotzen"],
    "New" : "Berria",
    "\"{name}\" is an invalid file name." : "\"{name}\" ez da fitxategi izen baliogarria.",
    "File name cannot be empty." : "Fitxategi izena ezin da hutsa izan.",
    "Your storage is full, files can not be updated or synced anymore!" : "Zure biltegiratzea beterik dago, ezingo duzu aurrerantzean fitxategirik igo edo sinkronizatu!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Zure biltegiratzea nahiko beterik dago (%{usedSpacePercent})",
    "Favorited" : "Gogokoa",
    "Favorite" : "Gogokoa",
    "Folder" : "Karpeta",
    "New folder" : "Karpeta berria",
    "Upload" : "Igo",
    "A new file or folder has been <strong>created</strong>" : "Fitxategi edo karpeta berri bat <strong>sortu da</strong>",
    "A file or folder has been <strong>changed</strong>" : "Fitxategi edo karpeta bat <strong>aldatu da</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Fitxategi edo karpeta bat <strong>ezabatu da</strong>",
    "A file or folder has been <strong>restored</strong>" : "Fitxategia edo karpeta <strong>berrezarri</strong> da",
    "You created %1$s" : "Zuk sortua %1$s",
    "%2$s created %1$s" : "%2$sk sortua %1$s",
    "%1$s was created in a public folder" : "%1$s sortu da karpeta publiko batean",
    "You changed %1$s" : "%1$s aldatu duzu",
    "%2$s changed %1$s" : "%2$sk aldatuta %1$s",
    "You deleted %1$s" : "%1$s ezabatu duzu",
    "%2$s deleted %1$s" : "%2$sk ezabatuta %1$s",
    "You restored %1$s" : "Zuk %1$s berrezarri duzu",
    "%2$s restored %1$s" : "%2$sk %1$s berrezarri du",
    "Upload (max. %s)" : "Igo (max. %s)",
    "File handling" : "Fitxategien kudeaketa",
    "Maximum upload size" : "Igo daitekeen gehienezko tamaina",
    "max. possible: " : "max, posiblea:",
    "Save" : "Gorde",
    "Settings" : "Ezarpenak",
    "WebDAV" : "WebDAV",
    "Upload some content or sync with your devices!" : "Igo edukiren bat edo sinkronizatu zure gailuekin!",
    "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan",
    "Select all" : "Hautatu dena",
    "Upload too large" : "Igoera handiegia da",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Igotzen saiatzen ari zaren fitxategiak zerbitzari honek igotzeko onartzen duena baino handiagoak dira.",
    "No favorites" : "Gogokorik ez",
    "Files and folders you mark as favorite will show up here" : "Gogokotzat markatutako fitxategi eta karpeta hemen agertuko dira",
    "Text file" : "Testu fitxategia",
    "This operation is forbidden" : "Eragiketa hau debekatuta dago",
    "This directory is unavailable, please check the logs or contact the administrator" : "Direktoria ez dago eskuragarri; mesedez, log-ak begiratu edo harremanetan jarri administratzailearekin"
},
"nplurals=2; plural=(n != 1);");
